==> kubernetes-model-core-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/ComponentConditionFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface ComponentConditionFluent<A extends ComponentConditionFluent<A>> extends Fluent<A> {


    public String getError();
    public A withError(String error);
    public Boolean hasError();
    public A withNewError(StringBuilder arg1);
    public A withNewError(int[] arg1,int arg2,int arg3);
    public A withNewError(char[] arg1);
    public A withNewError(StringBuffer arg1);
    public A withNewError(byte[] arg1,int arg2);
    public A withNewError(byte[] arg1);
    public A withNewError(char[] arg1,int arg2,int arg3);
    public A withNewError(byte[] arg1,int arg2,int arg3);
    public A withNewError(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewError(String arg1);
    public String getMessage();
    public A withMessage(String message);
    public Boolean hasMessage();
    public A withNewMessage(StringBuilder arg1);
    public A withNewMessage(int[] arg1,int arg2,int arg3);
    public A withNewMessage(char[] arg1);
    public A withNewMessage(StringBuffer arg1);
    public A withNewMessage(byte[] arg1,int arg2);
    public A withNewMessage(byte[] arg1);
    public A withNewMessage(char[] arg1,int arg2,int arg3);
    public A withNewMessage(byte[] arg1,int arg2,int arg3);
    public A withNewMessage(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewMessage(String arg1);
    public String getStatus();
    public A withStatus(String status);
    public Boolean hasStatus();
    public A withNewStatus(StringBuilder arg1);
    public A withNewStatus(int[] arg1,int arg2,int arg3);
    public A withNewStatus(char[] arg1);
    public A withNewStatus(StringBuffer arg1);
    public A withNewStatus(byte[] arg1,int arg2);
    public A withNewStatus(byte[] arg1);
    public A withNewStatus(char[] arg1,int arg2,int arg3);
    public A withNewStatus(byte[] arg1,int arg2,int arg3);
    public A withNewStatus(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewStatus(String arg1);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(StringBuilder arg1);
    public A withNewType(int[] arg1,int arg2,int arg3);
    public A withNewType(char[] arg1);
    public A withNewType(StringBuffer arg1);
    public A withNewType(byte[] arg1,int arg2);
    public A withNewType(byte[] arg1);
    public A withNewType(char[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewType(String arg1);
}

==> kubernetes-model-core-5.3.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/ComponentConditionFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface ComponentConditionFluent<A extends ComponentConditionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getError();
    public A withError(String error);
    public Boolean hasError();
    public A withNewError(StringBuilder arg1);
    public A withNewError(int[] arg1,int arg2,int arg3);
    public A withNewError(char[] arg1);
    public A withNewError(StringBuffer arg1);
    public A withNewError(byte[] arg1,int arg2);
    public A withNewError(byte[] arg1);
    public A withNewError(char[] arg1,int arg2,int arg3);
    public A withNewError(byte[] arg1,int arg2,int arg3);
    public A withNewError(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewError(String arg1);
    public String getMessage();
    public A withMessage(String message);
    public Boolean hasMessage();
    public A withNewMessage(StringBuilder arg1);
    public A withNewMessage(int[] arg1,int arg2,int arg3);
    public A withNewMessage(char[] arg1);
    public A withNewMessage(StringBuffer arg1);
    public A withNewMessage(byte[] arg1,int arg2);
    public A withNewMessage(byte[] arg1);
    public A withNewMessage(char[] arg1,int arg2,int arg3);
    public A withNewMessage(byte[] arg1,int arg2,int arg3);
    public A withNewMessage(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewMessage(String arg1);
    public String getStatus();
    public A withStatus(String status);
    public Boolean hasStatus();
    public A withNewStatus(StringBuilder arg1);
    public A withNewStatus(int[] arg1,int arg2,int arg3);
    public A withNewStatus(char[] arg1);
    public A withNewStatus(StringBuffer arg1);
    public A withNewStatus(byte[] arg1,int arg2);
    public A withNewStatus(byte[] arg1);
    public A withNewStatus(char[] arg1,int arg2,int arg3);
    public A withNewStatus(byte[] arg1,int arg2,int arg3);
    public A withNewStatus(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewStatus(String arg1);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(StringBuilder arg1);
    public A withNewType(int[] arg1,int arg2,int arg3);
    public A withNewType(char[] arg1);
    public A withNewType(StringBuffer arg1);
    public A withNewType(byte[] arg1,int arg2);
    public A withNewType(byte[] arg1);
    public A withNewType(char[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewType(String arg1);
}
